@@ -12,6 +12,8 @@ class BaseClient:
         if use_ssl:
             self.proto += 's'
         self.api_url_core = self.proto + '://' + self.host + ':' + str(self.port) + '/api/v{}'
+        self.username = None
+        self.password = None
 
 
 
